BrandingAsset

Struct BrandingAsset 

pub struct BrandingAsset {
Show 36 fields pub timeout: i32, pub test: bool, pub success: bool, pub error: String, pub response_description: String, pub id: String, pub owner_id: String, pub terminal_id: String, pub terminal_group_id: String, pub merchant_id: String, pub organization_id: String, pub partner_id: String, pub slide_show_id: String, pub media_id: String, pub padded: bool, pub start_date: String, pub end_date: String, pub days_of_week: Option<Vec<i8>>, pub start_time: String, pub end_time: String, pub ordinal: i32, pub enabled: bool, pub preview: bool, pub user_id: String, pub user_name: String, pub thumbnail: String, pub last_modified: String, pub notes: String, pub editable: bool, pub asset_type: String, pub owner_type: String, pub owner_type_caption: String, pub owner_name: String, pub preview_image: String, pub narrative_effective_dates: String, pub narrative_display_period: String,
}
Models the priority and display settings for terminal media.

Fields

timeout: i32

The request timeout in seconds.

test: bool

Whether or not to route transaction to the test gateway.

success: bool

Whether or not the request succeeded.

error: String

The error, if an error occurred.

response_description: String

A narrative description of the transaction result.

id: String

Id used to track a branding asset.

owner_id: String

The id owner of the tenant who owns the branding asset.

terminal_id: String

The terminal id if this branding asset is specific to a single terminal.

terminal_group_id: String

The terminal group id if this branding asset is specific to a terminal group.

merchant_id: String

The merchant id associated with this branding asset.

organization_id: String

The organization id associated with this branding asset.

partner_id: String

The partner id associated with this branding asset.

slide_show_id: String

The slide show associated with this branding asset, if any. A branding asset can reference a slide show or media asset, but not both.

media_id: String

The media id associated with this branding asset, if any. A branding asset can reference a slide show or media asset, but not both.

padded: bool

Applies standard margins to images displayed on terminals. Usually the best option for logos.

start_date: String

The start date if this asset should be displayed based on a schedule. Format: MM/DD/YYYY.

end_date: String

The end date if this asset should be displayed based on a schedule. Format: MM/DD/YYYY.

days_of_week: Option<Vec<i8>>

An array of days of the week during which a branding asset should be enabled. Days of the week are coded as integers starting with Sunday (0) and ending with Saturday (6).

start_time: String

The start date if this asset should be displayed based on a schedule. Format: MM/DD/YYYY.

end_time: String

The end date if this asset should be displayed based on a schedule. Format: MM/DD/YYYY.

ordinal: i32

The ordinal number marking the position of this asset within the branding stack.

enabled: bool

Enables the asset for display.

preview: bool

If true, the asset will be displayed in the merchant portal, but not on merchant terminal hardware. Developers will usually want this to always be false.

user_id: String

Id of the user who created this branding asset, if applicable.

user_name: String

Name of the user who created this branding asset, if applicable.

thumbnail: String

The fully qualified URL of the thumbnail image for this branding asset.

last_modified: String

The time and date this asset was last modified.

notes: String

A field for notes related to a branding asset.

editable: bool

If true, the API credentials used to retrieve the branding asset record can be used to update it.

asset_type: String

The type of branding asset.

owner_type: String

The type of user or tenant that owns this asset.

owner_type_caption: String

A recommended caption for displaying the owner. Takes into account multiple organization types.

owner_name: String

The name of the tenant or entity that owns the branding asset.

preview_image: String

The recommended image to be displayed when rendering a preview of this branding asset.

narrative_effective_dates: String

A compact narrative string explaining the effective date and time rules for a branding asset.

narrative_display_period: String

A compact narrative string explaining the display period for a branding asset.