pub struct BrandingAssetRequest {
pub timeout: i32,
pub test: bool,
pub asset_id: String,
}Expand description
Models a request to retrieve or manipulate terminal slide shows.
Fields
timeout: i32The request timeout in seconds.
test: boolWhether or not to route transaction to the test gateway.
asset_id: StringId used to track a branding asset.