CardMetadataResponse

Struct CardMetadataResponse 

pub struct CardMetadataResponse {
Show 23 fields pub success: bool, pub error: String, pub response_description: String, pub token: String, pub entry_method: String, pub payment_type: String, pub network: String, pub logo: String, pub masked_pan: String, pub public_key: String, pub scope_alert: bool, pub card_holder: String, pub exp_month: String, pub exp_year: String, pub postal_code: String, pub address: String, pub country: String, pub avs_response: AVSResponse, pub cvv_response: String, pub receipt_suggestions: ReceiptSuggestions, pub customer: Option<Customer>, pub customers: Option<Vec<Customer>>, pub card_metadata: Option<CardMetadata>,
}
The response to a card metadata request.

Fields

success: bool

Whether or not the request succeeded.

error: String

The error, if an error occurred.

response_description: String

A narrative description of the transaction result.

token: String

The payment token, if the payment was enrolled in the vault.

entry_method: String

The entry method for the transaction (CHIP, MSR, KEYED, etc).

payment_type: String

The card brand (VISA, MC, AMEX, DEBIT, etc).

network: String

Provides network level detail on how a transaction was routed, especially for debit transactions.

Identifies the card association based on bin number. Used primarily used to indicate the major logo on a card, even when debit transactions are routed on a different network.

masked_pan: String

The masked primary account number.

public_key: String

The BlockChyp public key if the user presented a BlockChyp payment card.

scope_alert: bool

That the transaction did something that would put the system in PCI scope.

card_holder: String

The cardholder name.

exp_month: String

The card expiration month in MM format.

exp_year: String

The card expiration year in YY format.

postal_code: String

The card postal code.

address: String

The card address.

country: String

The card country.

avs_response: AVSResponse

Address verification results if address information was submitted.

cvv_response: String

The CVV verification result if CVV was submitted.

receipt_suggestions: ReceiptSuggestions

Suggested receipt fields.

customer: Option<Customer>

Customer data, if any. Preserved for reverse compatibility.

customers: Option<Vec<Customer>>

Customer data, if any.

card_metadata: Option<CardMetadata>

Details about a payment card derived from its BIN/IIN.