pub struct HealthcareGroup {
pub type_yo: HealthcareType,
pub amount: String,
pub provider_id: String,
pub service_type_code: String,
pub payer_or_carrier_id: String,
pub approval_reject_reason_code: String,
}Expand description
A group of fields for a specific type of healthcare.
Fields
type_yo: HealthcareTypeThe type of healthcare cost.
amount: StringThe amount of this type.
provider_id: StringThe provider ID used for Mastercard and Discover IIAS requests.
service_type_code: StringThe service type code used for Mastercard and Discover IIAS requests.
payer_or_carrier_id: StringThr payer ID/carrier ID used for Mastercard and Discover IIAS requests.
approval_reject_reason_code: StringThe approval or reject reason code used for Mastercard and Discover IIAS requests.