pub struct PartnerStatementDisbursement {
pub id: String,
pub timestamp: DateTime<Utc>,
pub transaction_type: String,
pub payment_type: String,
pub masked_pan: String,
pub pending: bool,
pub approved: bool,
pub response_description: String,
pub amount: f64,
pub amount_formatted: String,
}Expand description
Models details about disbursements related to partner statements.
Fields
id: StringThe disbursement id.
timestamp: DateTime<Utc>Date and time the disbursement was processed.
transaction_type: StringThe type of disbursement transaction.
payment_type: StringThe payment method used to fund the disbursement.
masked_pan: StringThe masked account number into which funds were deposited.
pending: boolThat payment is still pending.
approved: boolThat payment is approved.
response_description: StringA response description from the disbursement payment platform, in any.
amount: f64The amount disbursed in floating point format.
amount_formatted: StringThe currency formatted form of amount.