pub struct SignatureRequest {
pub sig_file: String,
pub sig_format: SignatureFormat,
pub sig_width: i32,
pub disable_signature: bool,
}Expand description
A request for customer signature data.
Fields
sig_file: StringA location on the filesystem which a customer signature should be written to.
sig_format: SignatureFormatThe image format to be used for returning signatures.
sig_width: i32The width that the signature image should be scaled to, preserving the aspect ratio. If not provided, the signature is returned in the terminal’s max resolution.
disable_signature: boolWhether or not signature prompt should be skipped on the terminal. The terminal will indicate whether or not a signature is required by the card in the receipt suggestions response.