pub struct BrandingAsset {Show 36 fields
pub timeout: i32,
pub test: bool,
pub success: bool,
pub error: String,
pub response_description: String,
pub id: String,
pub owner_id: String,
pub terminal_id: String,
pub terminal_group_id: String,
pub merchant_id: String,
pub organization_id: String,
pub partner_id: String,
pub slide_show_id: String,
pub media_id: String,
pub padded: bool,
pub start_date: String,
pub end_date: String,
pub days_of_week: Option<Vec<i8>>,
pub start_time: String,
pub end_time: String,
pub ordinal: i32,
pub enabled: bool,
pub preview: bool,
pub user_id: String,
pub user_name: String,
pub thumbnail: String,
pub last_modified: String,
pub notes: String,
pub editable: bool,
pub asset_type: String,
pub owner_type: String,
pub owner_type_caption: String,
pub owner_name: String,
pub preview_image: String,
pub narrative_effective_dates: String,
pub narrative_display_period: String,
}Expand description
Models the priority and display settings for terminal media.
Fields
timeout: i32The request timeout in seconds.
test: boolWhether or not to route transaction to the test gateway.
success: boolWhether or not the request succeeded.
error: StringThe error, if an error occurred.
response_description: StringA narrative description of the transaction result.
id: StringId used to track a branding asset.
owner_id: StringThe id owner of the tenant who owns the branding asset.
terminal_id: StringThe terminal id if this branding asset is specific to a single terminal.
terminal_group_id: StringThe terminal group id if this branding asset is specific to a terminal group.
merchant_id: StringThe merchant id associated with this branding asset.
organization_id: StringThe organization id associated with this branding asset.
partner_id: StringThe partner id associated with this branding asset.
slide_show_id: StringThe slide show associated with this branding asset, if any. A branding asset can reference a slide show or media asset, but not both.
media_id: StringThe media id associated with this branding asset, if any. A branding asset can reference a slide show or media asset, but not both.
padded: boolApplies standard margins to images displayed on terminals. Usually the best option for logos.
start_date: StringThe start date if this asset should be displayed based on a schedule. Format: MM/DD/YYYY.
end_date: StringThe end date if this asset should be displayed based on a schedule. Format: MM/DD/YYYY.
days_of_week: Option<Vec<i8>>An array of days of the week during which a branding asset should be enabled. Days of the week are coded as integers starting with Sunday (0) and ending with Saturday (6).
start_time: StringThe start date if this asset should be displayed based on a schedule. Format: MM/DD/YYYY.
end_time: StringThe end date if this asset should be displayed based on a schedule. Format: MM/DD/YYYY.
ordinal: i32The ordinal number marking the position of this asset within the branding stack.
enabled: boolEnables the asset for display.
preview: boolIf true, the asset will be displayed in the merchant portal, but not on merchant terminal hardware. Developers will usually want this to always be false.
user_id: StringId of the user who created this branding asset, if applicable.
user_name: StringName of the user who created this branding asset, if applicable.
thumbnail: StringThe fully qualified URL of the thumbnail image for this branding asset.
last_modified: StringThe time and date this asset was last modified.
notes: StringA field for notes related to a branding asset.
editable: boolIf true, the API credentials used to retrieve the branding asset record can be used to update it.
asset_type: StringThe type of branding asset.
owner_type: StringThe type of user or tenant that owns this asset.
owner_type_caption: StringA recommended caption for displaying the owner. Takes into account multiple organization types.
owner_name: StringThe name of the tenant or entity that owns the branding asset.
preview_image: StringThe recommended image to be displayed when rendering a preview of this branding asset.
narrative_effective_dates: StringA compact narrative string explaining the effective date and time rules for a branding asset.
narrative_display_period: StringA compact narrative string explaining the display period for a branding asset.