pub struct CardMetadataResponse {Show 23 fields
pub success: bool,
pub error: String,
pub response_description: String,
pub token: String,
pub entry_method: String,
pub payment_type: String,
pub network: String,
pub logo: String,
pub masked_pan: String,
pub public_key: String,
pub scope_alert: bool,
pub card_holder: String,
pub exp_month: String,
pub exp_year: String,
pub postal_code: String,
pub address: String,
pub country: String,
pub avs_response: AVSResponse,
pub cvv_response: String,
pub receipt_suggestions: ReceiptSuggestions,
pub customer: Option<Customer>,
pub customers: Option<Vec<Customer>>,
pub card_metadata: Option<CardMetadata>,
}Expand description
The response to a card metadata request.
Fields
success: boolWhether or not the request succeeded.
error: StringThe error, if an error occurred.
response_description: StringA narrative description of the transaction result.
token: StringThe payment token, if the payment was enrolled in the vault.
entry_method: StringThe entry method for the transaction (CHIP, MSR, KEYED, etc).
payment_type: StringThe card brand (VISA, MC, AMEX, DEBIT, etc).
network: StringProvides network level detail on how a transaction was routed, especially for debit transactions.
logo: StringIdentifies the card association based on bin number. Used primarily used to indicate the major logo on a card, even when debit transactions are routed on a different network.
masked_pan: StringThe masked primary account number.
public_key: StringThe BlockChyp public key if the user presented a BlockChyp payment card.
scope_alert: boolThat the transaction did something that would put the system in PCI scope.
card_holder: StringThe cardholder name.
exp_month: StringThe card expiration month in MM format.
exp_year: StringThe card expiration year in YY format.
postal_code: StringThe card postal code.
address: StringThe card address.
country: StringThe card country.
avs_response: AVSResponseAddress verification results if address information was submitted.
cvv_response: StringThe CVV verification result if CVV was submitted.
receipt_suggestions: ReceiptSuggestionsSuggested receipt fields.
customer: Option<Customer>Customer data, if any. Preserved for reverse compatibility.
customers: Option<Vec<Customer>>Customer data, if any.
card_metadata: Option<CardMetadata>Details about a payment card derived from its BIN/IIN.