pub struct ListQueuedTransactionsRequest {Show 13 fields
pub timeout: i32,
pub test: bool,
pub transaction_ref: String,
pub autogenerated_ref: bool,
pub async_yo: bool,
pub queue: bool,
pub wait_for_removed_card: bool,
pub force: bool,
pub order_ref: String,
pub destination_account: String,
pub test_case: String,
pub terminal_name: String,
pub reset_connection: bool,
}Expand description
Returns a list of queued transactions on a terminal.
Fields
timeout: i32The request timeout in seconds.
test: boolWhether or not to route transaction to the test gateway.
transaction_ref: StringA user-assigned reference that can be used to recall or reverse transactions.
autogenerated_ref: boolThat the transaction reference was autogenerated and should be ignored for the purposes of duplicate detection.
async_yo: boolDefers the response to the transaction and returns immediately. Callers should retrive the transaction result using the Transaction Status API.
queue: boolAdds the transaction to the queue and returns immediately. Callers should retrive the transaction result using the Transaction Status API.
wait_for_removed_card: boolWhether or not the request should block until all cards have been removed from the card reader.
force: boolOverride any in-progress transactions.
order_ref: StringAn identifier from an external point of sale system.
destination_account: StringThe settlement account for merchants with split settlements.
test_case: StringCan include a code used to trigger simulated conditions for the purposes of testing and certification. Valid for test merchant accounts only.
terminal_name: StringThe name of the target payment terminal.
reset_connection: boolForces the terminal cloud connection to be reset while a transactions is in flight. This is a diagnostic settings that can be used only for test transactions.