pub struct PartnerStatementLineItem {Show 27 fields
pub id: String,
pub invoice_id: String,
pub total_fees: f64,
pub total_fees_formatted: String,
pub total_fees_on_volume: f64,
pub total_fees_on_volume_formatted: String,
pub merchant_id: String,
pub merchant_name: String,
pub dba_name: String,
pub statement_date: DateTime<Utc>,
pub volume: f64,
pub volume_formatted: String,
pub transaction_count: i64,
pub interchange: f64,
pub interchange_formatted: String,
pub interchange_on_volume: f64,
pub interchange_on_volume_formatted: String,
pub assessments: f64,
pub assessments_formatted: String,
pub assessments_on_volume: f64,
pub assessments_on_volume_formatted: String,
pub partner_commission: f64,
pub partner_commission_formatted: String,
pub buy_rate: f64,
pub buy_rate_formatted: String,
pub hard_costs: f64,
pub hard_costs_formatted: String,
}Expand description
Models line item level data for a partner statement.
Fields
id: StringThe line item id.
invoice_id: StringThe invoice id for the underlying merchant statement.
total_fees: f64The total fees charged to the merchant.
total_fees_formatted: StringThe total fees charge formatted as a currency string.
total_fees_on_volume: f64The total fees charged to the merchant as ratio of volume.
total_fees_on_volume_formatted: StringThe total fees charged to the merchant as percentage of volume.
merchant_id: StringThe id of the merchant.
merchant_name: StringThe corporate name of the merchant.
dba_name: StringThe dba name of the merchant.
statement_date: DateTime<Utc>The date the statement was generated.
volume: f64Volume in numeric format.
volume_formatted: StringThe string formatted total volume on the statement.
transaction_count: i64The total volume on the statement.
interchange: f64The total interchange fees incurred this period.
interchange_formatted: StringThe currency formatted form of interchange.
interchange_on_volume: f64The total interchange as a ratio on volume incurred this period.
interchange_on_volume_formatted: StringThe total interchange as a percentage of volume.
assessments: f64The total card brand assessments fees incurred this period.
assessments_formatted: StringThe currency formatted form of card brand assessments.
assessments_on_volume: f64The total card brand assessments as a ratio on volume incurred this period.
assessments_on_volume_formatted: StringThe total card brand assessments as a percentage of volume.
partner_commission: f64The commission earned on the portfolio during the statement period.
partner_commission_formatted: StringThe string formatted total volume on the statement.
buy_rate: f64The total fees charge to the partner due to buy rates.
buy_rate_formatted: StringThe currency formatted form of partner buy rate.
hard_costs: f64Refers to card brand fees shared between BlockChyp and the partner.
hard_costs_formatted: StringThe currency formatted form of hard costs.