pub struct PricingPolicyResponse {Show 34 fields
pub success: bool,
pub error: String,
pub response_description: String,
pub id: String,
pub partner_id: String,
pub merchant_id: String,
pub enabled: bool,
pub timestamp: String,
pub description: String,
pub policy_type: String,
pub partner_markup_split: String,
pub standard_flat_rate: PricePoint,
pub debit_flat_rate: PricePoint,
pub ecommerce_flat_rate: PricePoint,
pub keyed_flat_rate: PricePoint,
pub premium_flat_rate: PricePoint,
pub standard_interchange_markup: PricePoint,
pub debit_interchange_markup: PricePoint,
pub ecommerce_interchange_markup: PricePoint,
pub keyed_interchange_markup: PricePoint,
pub premium_interchange_markup: PricePoint,
pub standard_transaction_fee: PricePoint,
pub debit_transaction_fee: PricePoint,
pub ecommerce_transaction_fee: PricePoint,
pub keyed_transaction_fee: PricePoint,
pub premium_transaction_fee: PricePoint,
pub ebt_transaction_fee: PricePoint,
pub monthly_fee: PricePoint,
pub annual_fee: PricePoint,
pub chargeback_fee: PricePoint,
pub avs_fee: PricePoint,
pub batch_fee: PricePoint,
pub voice_auth_fee: PricePoint,
pub account_setup_fee: PricePoint,
}Expand description
Models a the response to a pricing policy request.
Fields
success: boolWhether or not the request succeeded.
error: StringThe error, if an error occurred.
response_description: StringA narrative description of the transaction result.
id: StringThe id owner of the pricing policy.
partner_id: StringThe id of the partner associated with this pricing policy.
merchant_id: StringThe id of the merchant associated with this pricing policy.
enabled: boolWhether or not a pricing policy is enabled.
timestamp: StringThe date and time when the pricing policy was created.
description: StringThe description of the pricing policy.
policy_type: StringType of pricing policy (flat vs interchange).
partner_markup_split: StringThe percentage split of the of buy rate markup with BlockChyp.
standard_flat_rate: PricePointThe flat rate percentage for standard card present transactions.
debit_flat_rate: PricePointThe flat rate percentage for debit card transactions.
ecommerce_flat_rate: PricePointThe flat rate percentage for ecommerce transactions.
keyed_flat_rate: PricePointThe flat rate percentage for keyed/manual transactions.
The flat rate percentage for premium (high rewards) card transactions.
standard_interchange_markup: PricePointThe interchange markup percentage for standard card present transactions.
debit_interchange_markup: PricePointThe interchange markup percentage for debit card transactions.
ecommerce_interchange_markup: PricePointThe interchange markup percentage for ecommerce transactions.
keyed_interchange_markup: PricePointThe interchange markup percentage for keyed/manual transactions.
The interchange markup percentage for premium (high rewards) card transactions.
standard_transaction_fee: PricePointThe transaction fee for standard card present transactions.
debit_transaction_fee: PricePointThe transaction fee for debit card transactions.
ecommerce_transaction_fee: PricePointThe transaction fee for ecommerce transactions.
keyed_transaction_fee: PricePointThe transaction fee for keyed/manual transactions.
The transaction fee for premium (high rewards) card transactions.
ebt_transaction_fee: PricePointThe transaction fee for EBT card transactions.
monthly_fee: PricePointA flat fee charged per month.
annual_fee: PricePointA flat fee charged per year.
chargeback_fee: PricePointThe fee per dispute or chargeback.
avs_fee: PricePointThe fee per address verification operation.
batch_fee: PricePointThe fee per batch.
voice_auth_fee: PricePointThe voice authorization fee.
account_setup_fee: PricePointThe one time account setup fee.