pub struct SubmitApplicationRequest {Show 51 fields
pub timeout: i32,
pub test: bool,
pub invite_code: String,
pub dba_name: String,
pub corporate_name: String,
pub web_site: String,
pub tax_id_number: String,
pub entity_type: String,
pub state_of_incorporation: String,
pub merchant_type: String,
pub business_description: String,
pub years_in_business: String,
pub business_phone_number: String,
pub physical_address: Address,
pub mailing_address: Address,
pub contact_first_name: String,
pub contact_last_name: String,
pub contact_phone_number: String,
pub contact_email: String,
pub contact_title: String,
pub contact_tax_id_number: String,
pub contact_dob: String,
pub contact_dl_number: String,
pub contact_dl_state_or_province: String,
pub contact_dl_expiration: String,
pub contact_home_address: Address,
pub contact_role: String,
pub owners: Option<Vec<Owner>>,
pub manual_account: ApplicationAccount,
pub average_transaction: String,
pub high_transaction: String,
pub average_month: String,
pub high_month: String,
pub refund_policy: String,
pub refund_days: String,
pub time_zone: String,
pub batch_close_time: String,
pub multiple_locations: String,
pub location_name: String,
pub store_number: String,
pub ebt_requested: String,
pub fns_number: String,
pub ecommerce: String,
pub drop_shipping: bool,
pub card_present_percentage: String,
pub phone_order_percentage: String,
pub ecom_percentage: String,
pub bill_before_shipment_days: String,
pub subscriptions_supported: String,
pub subscription_frequency: String,
pub signer_name: String,
}Expand description
Models a merchant application submission request to add a new merchant account.
Fields
timeout: i32The request timeout in seconds.
test: boolWhether or not to route transaction to the test gateway.
invite_code: StringThe invite code for the merchant.
dba_name: StringThe business name your customers know you by (DBA Name).
corporate_name: StringThe name of the legal entity you file your taxes under.
web_site: StringThe business website.
tax_id_number: StringThe business tax identification number (EIN).
entity_type: StringThe type of business entity.
state_of_incorporation: StringThe state where the business is incorporated.
merchant_type: StringThe primary type of business (e.g., Retail, Service, etc.).
business_description: StringA short description of the products and services sold.
years_in_business: StringThe number of years the business has been operating.
business_phone_number: StringThe business telephone number.
physical_address: AddressThe physical address of the business.
mailing_address: AddressThe mailing address of the business.
contact_first_name: StringThe first name of the primary contact.
contact_last_name: StringThe last name of the primary contact.
contact_phone_number: StringThe phone number of the primary contact.
contact_email: StringThe email address of the primary contact.
contact_title: StringThe job title of the primary contact.
contact_tax_id_number: StringThe tax identification number (SSN) of the primary contact.
contact_dob: StringThe date of birth of the primary contact.
contact_dl_number: StringThe driver’s license number of the primary contact.
contact_dl_state_or_province: StringThe state that issued the primary contact’s driver’s license.
contact_dl_expiration: StringThe expiration date of the primary contact’s driver’s license.
contact_home_address: AddressThe home address of the primary contact.
contact_role: StringThe role of the primary contact in the business.
owners: Option<Vec<Owner>>List of individuals with 25% or more ownership in the company.
manual_account: ApplicationAccountThe bank account information for the business.
average_transaction: StringThe average transaction amount.
high_transaction: StringThe highest expected transaction amount.
average_month: StringThe average monthly transaction volume.
high_month: StringThe highest expected monthly transaction volume.
refund_policy: StringThe refund policy of the business.
refund_days: StringThe number of days after purchase that refunds can be issued.
time_zone: StringThe time zone of the business.
batch_close_time: StringThe time when the daily batch should close.
multiple_locations: StringIndicates if the business has multiple locations.
location_name: StringThe name of this specific business location.
store_number: StringThe store number for this location.
ebt_requested: StringIndicates if the business wants to accept EBT cards.
fns_number: StringThe FNS number issued by the USDA for EBT processing.
ecommerce: StringIndicates if the business plans to accept payments through a website.
drop_shipping: boolIndicates if suppliers ship products directly to customers.
card_present_percentage: StringThe percentage of transactions that will be chip or swipe.
phone_order_percentage: StringThe percentage of transactions that will be phone orders.
ecom_percentage: StringThe percentage of transactions that will be e-commerce.
bill_before_shipment_days: StringThe number of days before shipment that customers are charged.
subscriptions_supported: StringIndicates if the business plans to process recurring payments.
subscription_frequency: StringThe frequency of recurring payments (if applicable).
signer_name: StringThe full legal name of the person signing the application.